@@ -407,6 +407,6 @@ def casda_export_products(table, directory):
 
         # write spectrum as fits file
         spectrum_table = parse_spectrum_to_table(products.spec)
-        spectrum_tables.write('%s_spec.fits' % (filename_prefix), format='fits')
+        spectrum_table.write('%s_spec.fits' % (filename_prefix), format='fits')
 
     return
\ No newline at end of file
